==> eam-wshub-proxyclient-11.5-3-sources.jar: net/datastream/schemas/mp_functions/gridtoolbar/ObjectFactory.java <==

package net.datastream.schemas.mp_functions.gridtoolbar;

import javax.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the net.datastream.schemas.mp_functions.gridtoolbar package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: net.datastream.schemas.mp_functions.gridtoolbar
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link TOOLBAR }
     * 
     */
    public TOOLBAR createTOOLBAR() {
        return new TOOLBAR();
    }

    /**
     * Create an instance of {@link TOOLBAR.FIELDVALUES }
     * 
     */
    public TOOLBAR.FIELDVALUES createTOOLBARFIELDVALUES() {
        return new TOOLBAR.FIELDVALUES();
    }

    /**
     * Create an instance of {@link TOOLBAR.FIELDVALUES.ROW }
     * 
     */
    public TOOLBAR.FIELDVALUES.ROW createTOOLBARFIELDVALUESROW() {
        return new TOOLBAR.FIELDVALUES.ROW();
    }

    /**
     * Create an instance of {@link TOOLBAR.FIELD }
     * 
     */
    public TOOLBAR.FIELD createTOOLBARFIELD() {
        return new TOOLBAR.FIELD();
    }

    /**
     * Create an instance of {@link Option }
     * 
     */
    public Option createOption() {
        return new Option();
    }

    /**
     * Create an instance of {@link TOOLBAR.FIELDVALUES.ROW.Dataspylist_Options }
     * 
     */
    public TOOLBAR.FIELDVALUES.ROW.Dataspylist_Options createTOOLBARFIELDVALUESROWDataspylist_Options() {
        return new TOOLBAR.FIELDVALUES.ROW.Dataspylist_Options();
    }

    /**
     * Create an instance of {@link TOOLBAR.FIELDVALUES.ROW.Filterfields_Options }
     * 
     */
    public TOOLBAR.FIELDVALUES.ROW.Filterfields_Options createTOOLBARFIELDVALUESROWFilterfields_Options() {
        return new TOOLBAR.FIELDVALUES.ROW.Filterfields_Options();
    }

}

==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_functions/gridtoolbar/ObjectFactory.java <==

package net.datastream.schemas.mp_functions.gridtoolbar;

import jakarta.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the net.datastream.schemas.mp_functions.gridtoolbar package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: net.datastream.schemas.mp_functions.gridtoolbar
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link TOOLBAR }
     * 
     * @return
     *     the new instance of {@link TOOLBAR }
     */
    public TOOLBAR createTOOLBAR() {
        return new TOOLBAR();
    }

    /**
     * Create an instance of {@link TOOLBAR.FIELDVALUES }
     * 
     * @return
     *     the new instance of {@link TOOLBAR.FIELDVALUES }
     */
    public TOOLBAR.FIELDVALUES createTOOLBARFIELDVALUES() {
        return new TOOLBAR.FIELDVALUES();
    }

    /**
     * Create an instance of {@link TOOLBAR.FIELDVALUES.ROW }
     * 
     * @return
     *     the new instance of {@link TOOLBAR.FIELDVALUES.ROW }
     */
    public TOOLBAR.FIELDVALUES.ROW createTOOLBARFIELDVALUESROW() {
        return new TOOLBAR.FIELDVALUES.ROW();
    }

    /**
     * Create an instance of {@link TOOLBAR.FIELD }
     * 
     * @return
     *     the new instance of {@link TOOLBAR.FIELD }
     */
    public TOOLBAR.FIELD createTOOLBARFIELD() {
        return new TOOLBAR.FIELD();
    }

    /**
     * Create an instance of {@link Option }
     * 
     * @return
     *     the new instance of {@link Option }
     */
    public Option createOption() {
        return new Option();
    }

    /**
     * Create an instance of {@link TOOLBAR.FIELDVALUES.ROW.Dataspylist_Options }
     * 
     * @return
     *     the new instance of {@link TOOLBAR.FIELDVALUES.ROW.Dataspylist_Options }
     */
    public TOOLBAR.FIELDVALUES.ROW.Dataspylist_Options createTOOLBARFIELDVALUESROWDataspylist_Options() {
        return new TOOLBAR.FIELDVALUES.ROW.Dataspylist_Options();
    }

    /**
     * Create an instance of {@link TOOLBAR.FIELDVALUES.ROW.Filterfields_Options }
     * 
     * @return
     *     the new instance of {@link TOOLBAR.FIELDVALUES.ROW.Filterfields_Options }
     */
    public TOOLBAR.FIELDVALUES.ROW.Filterfields_Options createTOOLBARFIELDVALUESROWFilterfields_Options() {
        return new TOOLBAR.FIELDVALUES.ROW.Filterfields_Options();
    }

}
